@@ -712,7 +712,7 @@ void addSeparator(BenchmarksToRun& res) {
     return;
   }
   if (res.separatorsAfter.empty() ||
-      res.separatorsAfter.back() != separatorAfter) {
+      res.separatorsAfter.back() != (separatorAfter - 1)) {
     res.separatorsAfter.push_back(res.benchmarks.size() - 1);
   }
 }
@@ -823,8 +823,8 @@ runBenchmarksWithPrinterImpl(
   auto const globalSuspenderBaseline =
       runBenchmarkGetNSPerIteration(toRun.suspenderBaseline->func, 0);
 
-  BenchmarkSuspender::suspenderOverhead =
-      chrono::nanoseconds(static_cast<chrono::high_resolution_clock::rep>(
+  BenchmarkSuspender::suspenderOverhead = chrono::nanoseconds(
+      static_cast<chrono::high_resolution_clock::rep>(
           globalSuspenderBaseline.first));
 
   std::set<std::string> counterNames;
