@@ -43,6 +43,8 @@
 
 FOLLY_GFLAGS_DECLARE_bool(benchmark);
 FOLLY_GFLAGS_DECLARE_uint32(bm_result_width_chars);
+FOLLY_GFLAGS_DECLARE_int32(bm_min_iters);
+FOLLY_GFLAGS_DECLARE_int64(bm_max_iters);
 
 namespace folly {
 
@@ -380,24 +382,29 @@ void printResultComparison(
  * friends below.
  */
 
-#define BENCHMARK_IMPL(funName, stringName, rv, paramType, paramName)        \
-  static void funName(paramType);                                            \
-  [[maybe_unused]] static bool FB_ANONYMOUS_VARIABLE(follyBenchmarkUnused) = \
-      (::folly::addBenchmark(                                                \
-           __FILE__,                                                         \
-           stringName,                                                       \
-           [](paramType paramName) -> unsigned {                             \
-             funName(paramName);                                             \
-             return rv;                                                      \
-           }),                                                               \
-       true);                                                                \
+FOLLY_PUSH_WARNING
+FOLLY_CLANG_DISABLE_WARNING("-Wglobal-constructors")
+
+#define BENCHMARK_IMPL(funName, stringName, rv, paramType, paramName) \
+  static void funName(paramType);                                     \
+  [[maybe_unused]] static const bool FB_ANONYMOUS_VARIABLE(           \
+      follyBenchmarkUnused) =                                         \
+      (::folly::addBenchmark(                                         \
+           __FILE__,                                                  \
+           stringName,                                                \
+           [](paramType paramName) -> unsigned {                      \
+             funName(paramName);                                      \
+             return rv;                                               \
+           }),                                                        \
+       true);                                                         \
   static void funName(paramType paramName)
 
 #define BENCHMARK_IMPL_COUNTERS(                                             \
     funName, stringName, counters, rv, paramType, paramName)                 \
   static void funName(                                                       \
       ::folly::UserCounters& FOLLY_PP_DETAIL_APPEND_VA_ARG(paramType));      \
-  [[maybe_unused]] static bool FB_ANONYMOUS_VARIABLE(follyBenchmarkUnused) = \
+  [[maybe_unused]] static const bool FB_ANONYMOUS_VARIABLE(                  \
+      follyBenchmarkUnused) =                                                \
       (::folly::addBenchmark(                                                \
            __FILE__,                                                         \
            stringName,                                                       \
@@ -416,16 +423,19 @@ void printResultComparison(
  * number of iterations. Used internally, see BENCHMARK_MULTI and friends
  * below.
  */
-#define BENCHMARK_MULTI_IMPL(funName, stringName, paramType, paramName)      \
-  static unsigned funName(paramType);                                        \
-  [[maybe_unused]] static bool FB_ANONYMOUS_VARIABLE(follyBenchmarkUnused) = \
-      (::folly::addBenchmark(                                                \
-           __FILE__,                                                         \
-           stringName,                                                       \
-           [](paramType paramName) { return funName(paramName); }),          \
-       true);                                                                \
+#define BENCHMARK_MULTI_IMPL(funName, stringName, paramType, paramName) \
+  static unsigned funName(paramType);                                   \
+  [[maybe_unused]] static const bool FB_ANONYMOUS_VARIABLE(             \
+      follyBenchmarkUnused) =                                           \
+      (::folly::addBenchmark(                                           \
+           __FILE__,                                                    \
+           stringName,                                                  \
+           [](paramType paramName) { return funName(paramName); }),     \
+       true);                                                           \
   static unsigned funName(paramType paramName)
 
+FOLLY_POP_WARNING
+
 /**
  * Introduces a benchmark function. Use with either one or two arguments.
  * The first is the name of the benchmark. Use something descriptive, such
@@ -668,7 +678,8 @@ void printResultComparison(
  * Draws a line of dashes.
  */
 #define BENCHMARK_DRAW_LINE()                                                \
-  [[maybe_unused]] static bool FB_ANONYMOUS_VARIABLE(follyBenchmarkUnused) = \
+  [[maybe_unused]] static const bool FB_ANONYMOUS_VARIABLE(                  \
+      follyBenchmarkUnused) =                                                \
       (::folly::addBenchmark(__FILE__, "-", []() -> unsigned { return 0; }), \
        true)
 
@@ -676,7 +687,8 @@ void printResultComparison(
  * Prints arbitrary text.
  */
 #define BENCHMARK_DRAW_TEXT(text)                                              \
-  [[maybe_unused]] static bool FB_ANONYMOUS_VARIABLE(follyBenchmarkUnused) =   \
+  [[maybe_unused]] static const bool FB_ANONYMOUS_VARIABLE(                    \
+      follyBenchmarkUnused) =                                                  \
       (::folly::addBenchmark(__FILE__, #text, []() -> unsigned { return 0; }), \
        true)
 
