@@ -193,8 +193,9 @@ CacheLocality CacheLocality::readFromSysfsTree(std::string_view root) {
   auto checkNoEnt = [](std::string_view name) {
     auto err = errno;
     if (err != ENOENT) {
-      throw std::runtime_error(fmt::format(
-          "unexpected error while opening {}: {}", name, strerror(err)));
+      throw std::runtime_error(
+          fmt::format(
+              "unexpected error while opening {}: {}", name, strerror(err)));
     }
   };
 
@@ -589,6 +590,11 @@ class SimpleAllocator {
     }
   }
 
+  SimpleAllocator(const SimpleAllocator&) = delete;
+  SimpleAllocator& operator=(const SimpleAllocator&) = delete;
+  SimpleAllocator(SimpleAllocator&&) = delete;
+  SimpleAllocator& operator=(SimpleAllocator&&) = delete;
+
   void* allocate() {
     std::lock_guard g(m_);
     // Freelist allocation.
