@@ -186,7 +186,7 @@ using FallbackGetcpuType = FallbackGetcpu<
 namespace detail {
 
 class AccessSpreaderBase {
- protected:
+ public:
   /// If there are more cpus than this nothing will crash, but there
   /// might be unnecessary sharing
   enum {
@@ -194,6 +194,7 @@ class AccessSpreaderBase {
     kMaxCpus = kIsMobile ? 16 : 256,
   };
 
+ protected:
   using CompactStripe = uint8_t;
 
   static_assert(
@@ -473,11 +474,16 @@ class CoreAllocator : private std::allocator<T> {
   };
 };
 
-class FOLLY_NODISCARD CoreAllocatorGuard {
+class [[nodiscard]] CoreAllocatorGuard {
  public:
   CoreAllocatorGuard(size_t numStripes, size_t stripe);
   ~CoreAllocatorGuard();
 
+  CoreAllocatorGuard(const CoreAllocatorGuard&) = delete;
+  CoreAllocatorGuard& operator=(const CoreAllocatorGuard&) = delete;
+  CoreAllocatorGuard(CoreAllocatorGuard&&) = delete;
+  CoreAllocatorGuard& operator=(CoreAllocatorGuard&&) = delete;
+
  private:
   friend void* detail::coreMallocFromGuard(size_t size);
 
