@@ -122,15 +122,6 @@ static_assert(
 
 namespace {
 
-template <typename Key, typename Value, size_t N>
-using small_sorted_vector_map = folly::sorted_vector_map<
-    Key,
-    Value,
-    std::less<Key>,
-    std::allocator<std::pair<Key, Value>>,
-    void,
-    folly::small_vector<std::pair<Key, Value>, N>>;
-
 template <typename Key, typename Value, size_t N>
 using noheap_sorted_vector_map = folly::sorted_vector_map<
     Key,
@@ -140,14 +131,6 @@ using noheap_sorted_vector_map = folly::sorted_vector_map<
     void,
     folly::small_vector<std::pair<Key, Value>, N, policy_in_situ_only<true>>>;
 
-template <typename T, size_t N>
-using small_sorted_vector_set = folly::sorted_vector_set<
-    T,
-    std::less<T>,
-    std::allocator<T>,
-    void,
-    folly::small_vector<T, N>>;
-
 template <typename T, size_t N>
 using noheap_sorted_vector_set = folly::sorted_vector_set<
     T,
@@ -1266,7 +1249,7 @@ TEST(smallVector, CLVPushBackEfficiency) {
 }
 
 TEST(smallVector, StorageForSortedVectorMap) {
-  small_sorted_vector_map<int32_t, int32_t, 2> test;
+  folly::small_sorted_vector_map<int32_t, int32_t, 2> test;
   test.insert(std::make_pair(10, 10));
   EXPECT_EQ(test.size(), 1);
   test.insert(std::make_pair(10, 10));
@@ -1290,7 +1273,7 @@ TEST(smallVector, NoHeapStorageForSortedVectorMap) {
 }
 
 TEST(smallVector, StorageForSortedVectorSet) {
-  small_sorted_vector_set<int32_t, 2> test;
+  folly::small_sorted_vector_set<int32_t, 2> test;
   test.insert(10);
   EXPECT_EQ(test.size(), 1);
   test.insert(10);
