@@ -33,8 +33,8 @@
 #include <folly/ScopeGuard.h>
 #include <folly/Traits.h>
 #include <folly/Try.h>
+#include <folly/coro/BasePromise.h>
 #include <folly/coro/Coroutine.h>
-#include <folly/coro/CurrentExecutor.h>
 #include <folly/coro/Invoke.h>
 #include <folly/coro/Result.h>
 #include <folly/coro/ScopeExit.h>
@@ -74,9 +74,10 @@ class TaskPromisePrivate {
   TaskPromisePrivate() = default;
 };
 
-class TaskPromiseBase {
+class TaskPromiseBase : public BasePromise<> {
   static TaskPromisePrivate privateTag() { return TaskPromisePrivate{}; }
 
+ protected:
   class FinalAwaiter {
    public:
     bool await_ready() noexcept { return false; }
@@ -121,21 +122,9 @@ class TaskPromiseBase {
     [[noreturn]] void await_resume() noexcept { folly::assume_unreachable(); }
   };
 
-  friend class FinalAwaiter;
-
- protected:
   TaskPromiseBase() noexcept = default;
   ~TaskPromiseBase() = default;
 
-  template <typename Promise>
-  variant_awaitable<FinalAwaiter, ready_awaitable<>> do_safe_point(
-      Promise& promise) noexcept {
-    if (cancelToken_.isCancellationRequested()) {
-      return promise.yield_value(co_cancelled);
-    }
-    return ready_awaitable<>{};
-  }
-
  public:
   static void* operator new(std::size_t size) {
     return ::folly_coro_async_malloc(size);
@@ -149,62 +138,6 @@ class TaskPromiseBase {
 
   FinalAwaiter final_suspend() noexcept { return {}; }
 
-  template <
-      typename Awaitable,
-      std::enable_if_t<!folly::ext::must_use_immediately_v<Awaitable>, int> = 0>
-  auto await_transform(Awaitable&& awaitable) {
-    bypassExceptionThrowing_ =
-        bypassExceptionThrowing_ == BypassExceptionThrowing::REQUESTED
-        ? BypassExceptionThrowing::ACTIVE
-        : BypassExceptionThrowing::INACTIVE;
-
-    return folly::coro::co_withAsyncStack(folly::coro::co_viaIfAsync(
-        executor_.get_alias(),
-        folly::coro::co_withCancellation(
-            cancelToken_, static_cast<Awaitable&&>(awaitable))));
-  }
-  template <
-      typename Awaitable,
-      std::enable_if_t<folly::ext::must_use_immediately_v<Awaitable>, int> = 0>
-  auto await_transform(Awaitable awaitable) {
-    bypassExceptionThrowing_ =
-        bypassExceptionThrowing_ == BypassExceptionThrowing::REQUESTED
-        ? BypassExceptionThrowing::ACTIVE
-        : BypassExceptionThrowing::INACTIVE;
-
-    return folly::coro::co_withAsyncStack(folly::coro::co_viaIfAsync(
-        executor_.get_alias(),
-        folly::coro::co_withCancellation(
-            cancelToken_,
-            folly::ext::must_use_immediately_unsafe_mover(
-                std::move(awaitable))())));
-  }
-
-  template <typename Awaitable>
-  auto await_transform(NothrowAwaitable<Awaitable> awaitable) {
-    static_assert(!noexcept_awaitable_v<Awaitable>); // Doc on NothrowAwaitable
-    bypassExceptionThrowing_ = BypassExceptionThrowing::REQUESTED;
-    return await_transform(
-        folly::ext::must_use_immediately_unsafe_mover(awaitable.unwrap())());
-  }
-
-  auto await_transform(co_current_executor_t /*unused*/) noexcept {
-    return ready_awaitable<folly::Executor*>{executor_.get()};
-  }
-
-  auto await_transform(co_current_cancellation_token_t /*unused*/) noexcept {
-    return ready_awaitable<const folly::CancellationToken&>{cancelToken_};
-  }
-
-  void setCancelToken(folly::CancellationToken&& cancelToken) noexcept {
-    if (!hasCancelTokenOverride_) {
-      cancelToken_ = std::move(cancelToken);
-      hasCancelTokenOverride_ = true;
-    }
-  }
-
-  folly::AsyncStackFrame& getAsyncFrame() noexcept { return asyncFrame_; }
-
   folly::Executor::KeepAlive<> getExecutor() const noexcept {
     return executor_;
   }
@@ -233,19 +166,9 @@ class TaskPromiseBase {
     return std::exchange(p.scopeExit_, scopeExit);
   }
 
-  ExtendedCoroutineHandle continuation_;
-  folly::AsyncStackFrame asyncFrame_;
-  folly::Executor::KeepAlive<> executor_;
-  folly::CancellationToken cancelToken_;
+  // From the base: continuation_, asyncFrame_, executor_, cancelToken_,
+  // hasCancelTokenOverride_
   coroutine_handle<ScopeExitTaskPromiseBase> scopeExit_;
-  bool hasCancelTokenOverride_ = false;
-
- protected:
-  enum class BypassExceptionThrowing : uint8_t {
-    INACTIVE,
-    ACTIVE,
-    REQUESTED,
-  } bypassExceptionThrowing_{BypassExceptionThrowing::INACTIVE};
 };
 
 // Separate from `TaskPromiseBase` so the compiler has less to specialize.
@@ -274,23 +197,16 @@ class TaskPromiseCrtpBase
     return final_suspend();
   }
 
-  using TaskPromiseBase::await_transform;
+  using BasePromise<>::await_transform;
 
   auto await_transform(co_safe_point_t /*unused*/) noexcept {
-    return do_safe_point(*this);
+    return do_safe_point<FinalAwaiter>(*this);
   }
 
+  // Unlike `getErrorHandleUncheckedImpl`, checks the type of `me`.
   static std::optional<ExtendedCoroutineHandle::ErrorHandle> getErrorHandleImpl(
       Promise& me, exception_wrapper& ex) {
-    if (me.bypassExceptionThrowing_ == BypassExceptionThrowing::ACTIVE) {
-      auto finalAwaiter = me.yield_value(co_error(std::move(ex)));
-      DCHECK(!finalAwaiter.await_ready());
-      return ExtendedCoroutineHandle::ErrorHandle{
-          finalAwaiter.await_suspend_promise(me),
-          // finalAwaiter.await_suspend pops a frame
-          me.getAsyncFrame().getParentFrame()};
-    }
-    return std::nullopt;
+    return getErrorHandleUncheckedImpl(me, ex);
   }
 
  protected:
@@ -389,7 +305,7 @@ FOLLY_DEFINE_CPO(detail::adl::WithExecutorFunction, co_withExecutor)
 ///
 /// More information on how to use this is available at folly::coro::Task.
 template <typename T>
-class FOLLY_NODISCARD TaskWithExecutor {
+class [[nodiscard]] TaskWithExecutor {
   using handle_t = coroutine_handle<detail::TaskPromise<T>>;
   using StorageType = typename detail::TaskPromise<T>::StorageType;
 
@@ -491,7 +407,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
       F&& tryCallback,
       folly::CancellationToken cancelToken,
       void* returnAddress) && {
-    coro_.promise().setCancelToken(std::move(cancelToken));
+    coro_.promise().setCancellationToken(std::move(cancelToken));
     startImpl(std::move(*this), static_cast<F&&>(tryCallback))
         .start(returnAddress);
   }
@@ -501,7 +417,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
       F&& tryCallback,
       folly::CancellationToken cancelToken,
       void* returnAddress) && {
-    coro_.promise().setCancelToken(std::move(cancelToken));
+    coro_.promise().setCancellationToken(std::move(cancelToken));
     // If the task replaces the request context and reaches a suspension point,
     // it will not have a chance to restore the previous context before we
     // return, so we need to ensure it is restored. This simulates starting the
@@ -709,7 +625,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
   friend TaskWithExecutor co_withCancellation(
       folly::CancellationToken cancelToken, TaskWithExecutor&& task) noexcept {
     DCHECK(task.coro_);
-    task.coro_.promise().setCancelToken(std::move(cancelToken));
+    task.coro_.promise().setCancellationToken(std::move(cancelToken));
     return std::move(task);
   }
 
@@ -734,7 +650,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
 // This macro makes it easier for `TaskWrapper.h` users to apply the correct
 // attributes for the wrapped `Task`s.
 #define FOLLY_CORO_TASK_ATTRS \
-  FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]]
+  [[nodiscard]] [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]]
 
 /// Represents an allocated, but not-started coroutine, which is not yet
 /// been bound to an executor.
@@ -865,7 +781,7 @@ class FOLLY_CORO_TASK_ATTRS Task {
   friend Task co_withCancellation(
       folly::CancellationToken cancelToken, Task&& task) noexcept {
     DCHECK(task.coro_);
-    task.coro_.promise().setCancelToken(std::move(cancelToken));
+    task.coro_.promise().setCancellationToken(std::move(cancelToken));
     return std::move(task);
   }
 
@@ -875,8 +791,9 @@ class FOLLY_CORO_TASK_ATTRS Task {
       tag_t<Task, F, A...> /*unused*/,
       F_ f,
       A_... a) {
-    co_yield co_result(co_await co_awaitTry(
-        invoke(static_cast<F&&>(f), static_cast<A&&>(a)...)));
+    co_yield co_result(
+        co_await co_awaitTry(
+            invoke(static_cast<F&&>(f), static_cast<A&&>(a)...)));
   }
 
   using PrivateAwaiterTypeForTests = Awaiter;
