@@ -1017,8 +1017,8 @@ TEST_F(SharedMutexTest, StressTest) {
   coro::SharedMutex mutex;
   int value1 = 0;
   int value2 = 0;
-  std::atomic<bool> reachedTarget{false};
-  std::atomic<size_t> earlyExists{0};
+  folly::relaxed_atomic<bool> reachedTarget{false};
+  folly::relaxed_atomic<size_t> earlyExists{0};
   constexpr int target = 100'000;
 
   auto incrementIfEven = [&]() -> coro::Task<void> {
@@ -1073,7 +1073,7 @@ TEST_F(SharedMutexTest, StressTest) {
 
   size_t writeTaskCnt = 0;
   folly::coro::AsyncScope scope;
-  while (!reachedTarget.load()) {
+  while (!reachedTarget) {
     writeTaskCnt += 2;
     scope.add(co_withExecutor(&executor, check()));
     scope.add(co_withExecutor(&executor, incrementIfOdd()));
