@@ -20,6 +20,7 @@
 #include <folly/io/async/AsyncIoUringSocket.h>
 #include <folly/io/async/AsyncSocket.h>
 #include <folly/io/async/IoUringEventBaseLocal.h>
+#include <folly/io/async/IoUringProvidedBufferRing.h>
 #include <folly/memory/Malloc.h>
 #include <folly/portability/SysUio.h>
 
@@ -141,6 +142,7 @@ AsyncIoUringSocket::ReadSqe::ReadSqe(AsyncIoUringSocket* parent)
     : IoSqeBase(IoSqeBase::Type::Read), parent_(parent) {
   supportsMultishotRecv_ = parent->options_.multishotRecv &&
       parent->backend_->kernelSupportsRecvmsgMultishot();
+  useBundles_ = parent->options_.useBundles;
   // If the backend for this socket has an IoUringZeroCopyBufferPool, then zero
   // copy is enabled implicitly.
   supportsZeroCopyRx_ = parent->backend_->zcBufferPool() != nullptr;
@@ -631,8 +633,9 @@ void AsyncIoUringSocket::ReadSqe::callback(const io_uring_cqe* cqe) noexcept {
       }
     } else if (res > 0 && lastUsedBufferProvider_) {
       // must take the buffer
+      uint16_t bufId = flags >> IORING_CQE_BUFFER_SHIFT;
       appendReadData(
-          lastUsedBufferProvider_->getIoBuf(flags >> 16, res, hasMore),
+          lastUsedBufferProvider_->getIoBuf(bufId, res, hasMore),
           queuedReceivedData_);
       buffer_guard.dismiss();
     }
@@ -690,11 +693,10 @@ void AsyncIoUringSocket::ReadSqe::callback(const io_uring_cqe* cqe) noexcept {
         buffer_guard.dismiss();
       } else if (lastUsedBufferProvider_) {
         auto bufId = flags >> 16;
-        VLOG(9) << "Processing buffer completion: bufId=" << bufId
-                << " res=" << res << " hasMore=" << hasMore;
         sendReadBuf(
             lastUsedBufferProvider_->getIoBuf(bufId, res, hasMore),
             queuedReceivedData_);
+
         buffer_guard.dismiss();
       } else {
         // slow path as must have run out of buffers
@@ -773,6 +775,10 @@ void AsyncIoUringSocket::ReadSqe::processSubmit(
           used_len = maxSize_;
         }
 
+        if (useBundles_) {
+          ioprio_flags |= IORING_RECVSEND_BUNDLE;
+        }
+
         ::io_uring_prep_recv(sqe, fd, nullptr, used_len, 0);
         sqe->buf_group = lastUsedBufferProvider_->gid();
         sqe->flags |= IOSQE_BUFFER_SELECT;
@@ -1174,6 +1180,9 @@ void AsyncIoUringSocket::detachEventBase() {
   readSqe_ = ReadSqe::UniquePtr(new ReadSqe(this));
   readSqe_->setReadCallback(oldReadCallback, false);
   readSqe_->setEventBase(nullptr);
+  SocketAddress remoteAddr;
+  getPeerAddress(&remoteAddr);
+  readSqe_->setUseZeroCopyRx(!remoteAddr.isLoopbackAddress());
 
   unregisterFd();
   if (!drc) {
@@ -1187,16 +1196,17 @@ void AsyncIoUringSocket::detachEventBase() {
     auto res = drc->prom.getSemiFuture();
     if (previous) {
       VLOG(4) << "Setting promise from previous and this one";
-      readSqe_->setOldEventBaseRead(std::move(*previous).deferValue(
-          [r = std::move(res)](
-              std::unique_ptr<folly::IOBuf>&& prevRes) mutable {
-            return std::move(r).deferValue(
-                [p = std::move(prevRes)](
-                    std::unique_ptr<folly::IOBuf>&& nextRes) mutable {
-                  p->appendToChain(std::move(nextRes));
-                  return std::move(p);
-                });
-          }));
+      readSqe_->setOldEventBaseRead(
+          std::move(*previous).deferValue(
+              [r = std::move(res)](
+                  std::unique_ptr<folly::IOBuf>&& prevRes) mutable {
+                return std::move(r).deferValue(
+                    [p = std::move(prevRes)](
+                        std::unique_ptr<folly::IOBuf>&& nextRes) mutable {
+                      p->appendToChain(std::move(nextRes));
+                      return std::move(p);
+                    });
+              }));
     } else {
       VLOG(4) << "Setting promise from this one";
       readSqe_->setOldEventBaseRead(std::move(res));
@@ -1830,15 +1840,10 @@ void AsyncIoUringSocket::registerFd() {
 void AsyncIoUringSocket::setFd(NetworkSocket ns) {
   fd_ = ns;
   try {
-    if (!backend_->kernelHasNonBlockWriteFixes()) {
-      // If the kernel doesnt have the fixes we have to disable the nonblock
-      // flag It will still be NONBLOCK as long as it goes through io_uring, but
-      // if we leave the flag then IO_URING will spin on some ops.
-      int flags =
-          ensureSocketReturnCode(fcntl(ns.toFd(), F_GETFL, 0), "get flags");
-      flags = flags & ~O_NONBLOCK;
-      ensureSocketReturnCode(fcntl(ns.toFd(), F_SETFL, flags), "set flags");
-    }
+    int flags =
+        ensureSocketReturnCode(fcntl(ns.toFd(), F_GETFL, 0), "get flags");
+    flags = flags & ~O_NONBLOCK;
+    ensureSocketReturnCode(fcntl(ns.toFd(), F_SETFL, flags), "set flags");
     registerFd();
   } catch (std::exception const& e) {
     LOG(ERROR) << "unable to setFd " << ns.toFd() << " : " << e.what();
