@@ -32,6 +32,8 @@
 #include <folly/observer/WithJitter.h>
 #include <folly/portability/GMock.h>
 #include <folly/portability/GTest.h>
+#include <folly/synchronization/AsymmetricThreadFence.h>
+#include <folly/synchronization/AtomicUtil.h>
 #include <folly/synchronization/Baton.h>
 
 using namespace std::literals;
@@ -59,6 +61,14 @@ struct NamedCreator {
 };
 } // namespace
 
+template <>
+struct folly::atomic_thread_fence_traits<AltAtomic>
+    : folly::atomic_thread_fence_traits<std::atomic> {};
+
+template <>
+struct folly::asymmetric_thread_fence_traits<AltAtomic>
+    : folly::asymmetric_thread_fence_traits<std::atomic> {};
+
 namespace folly {
 namespace observer {
 
