@@ -25,6 +25,7 @@
 
 #include <glog/logging.h>
 
+#include <folly/ConstexprMath.h>
 #include <folly/String.h>
 #include <folly/stats/BucketedTimeSeries.h>
 
@@ -106,7 +107,7 @@ class MultiLevelTimeSeries {
    * not been called recently.
    */
   const Level& getLevel(size_t level) const {
-    CHECK_LT(level, levels_.size());
+    DCHECK_LT(level, levels_.size());
     return levels_[level];
   }
 
@@ -153,8 +154,9 @@ class MultiLevelTimeSeries {
         return level;
       }
     }
-    throw std::out_of_range(folly::to<std::string>(
-        "No level of duration ", duration.count(), " found"));
+    throw std::out_of_range(
+        folly::to<std::string>(
+            "No level of duration ", duration.count(), " found"));
   }
 
   /*
@@ -166,6 +168,19 @@ class MultiLevelTimeSeries {
    */
   ValueType sum(size_t level) const { return getLevel(level).sum(); }
 
+  /*
+   * Return the sum of all the data points currently tracked by this
+   * level, as if `update(now)` is called first. The user
+   * does NOT need to call `update(now)` separately.
+   *
+   * This is for providing a way for reading the timeseries without mutation.
+   */
+  ValueType sumBy(size_t level, TimePoint now) const {
+    auto [total, includeCache] = totalBy(level, now);
+    return constexpr_add_overflow_clamped(
+        total.sum, includeCache ? cachedSum_ : 0);
+  }
+
   /*
    * Return the average (sum / count) of all the data points currently tracked
    * at this level.
@@ -182,6 +197,23 @@ class MultiLevelTimeSeries {
     return getLevel(level).template avg<ReturnType>();
   }
 
+  /*
+   * Return the average (sum/count) of all the data points currently tracked by
+   * this level, as if `update(now)` is called first. The user does NOT need to
+   * call `update(now)` separately.
+   *
+   * This is for providing a way for reading the timeseries without mutation.
+   */
+  template <typename ReturnType = double>
+  ReturnType avgBy(size_t level, TimePoint now) const {
+    auto [total, includeCache] = totalBy(level, now);
+    return folly::detail::avgHelper<ReturnType>(
+        constexpr_add_overflow_clamped(
+            total.sum, includeCache ? cachedSum_ : 0),
+        constexpr_add_overflow_clamped(
+            total.count, includeCache ? cachedCount_ : 0));
+  }
+
   /*
    * Return the rate (sum divided by elaspsed time) of the all data points
    * currently tracked at this level.
@@ -195,6 +227,20 @@ class MultiLevelTimeSeries {
     return getLevel(level).template rate<ReturnType, Interval>();
   }
 
+  /*
+   * Return the rate (sum divided by elapsed time) of all the data points
+   * currently tracked by this level, as if `update(now)` is called first. The
+   * user does NOT need to call `update(now)` separately.
+   *
+   * This is for providing a way for reading the timeseries without mutation.
+   */
+  template <typename ReturnType = double, typename Interval = Duration>
+  ReturnType rateBy(size_t level, TimePoint now) const {
+    const auto& timeseries = getLevel(level);
+    return timeseries.template rateHelper<ReturnType, Interval>(
+        sumBy(level, now), elapsedBy(level, now));
+  }
+
   /*
    * Return the number of data points currently tracked at this level.
    *
@@ -204,6 +250,19 @@ class MultiLevelTimeSeries {
    */
   uint64_t count(size_t level) const { return getLevel(level).count(); }
 
+  /*
+   * Return the count of all the data points currently tracked by this
+   * level, as if `update(now)` is called first. The user
+   * does NOT need to call `update(now)` separately.
+   *
+   * This is for providing a way for reading the timeseries without mutation.
+   */
+  uint64_t countBy(size_t level, TimePoint now) const {
+    auto [total, includeCache] = totalBy(level, now);
+    return constexpr_add_overflow_clamped(
+        total.count, includeCache ? cachedCount_ : 0);
+  }
+
   /*
    * Return the count divided by the elapsed time tracked at this level.
    *
@@ -216,6 +275,20 @@ class MultiLevelTimeSeries {
     return getLevel(level).template countRate<ReturnType, Interval>();
   }
 
+  /*
+   * Return the count divided by elapsed time of all the data points currently
+   * tracked by this level, as if `update(now)` is called first. The user does
+   * NOT need to call `update(now)` separately.
+   *
+   * This is for providing a way for reading the timeseries without mutation.
+   */
+  template <typename ReturnType = double, typename Interval = Duration>
+  ReturnType countRateBy(size_t level, TimePoint now) const {
+    const auto& timeseries = getLevel(level);
+    return timeseries.template rateHelper<ReturnType, Interval>(
+        countBy(level, now), elapsedBy(level, now));
+  }
+
   /*
    * Return the sum of all the data points currently tracked at this level.
    *
@@ -426,6 +499,55 @@ class MultiLevelTimeSeries {
   }
 
  private:
+  Duration computeMaxCacheDuration();
+
+  Duration elapsedBy(size_t level, TimePoint now) const {
+    const auto& timeseries = getLevel(level);
+    TimePoint firstTime = now;
+    if (cachedCount_ != 0) {
+      firstTime = std::min(firstTime, cachedTime_);
+    }
+    if (!timeseries.empty()) {
+      firstTime = std::min(firstTime, timeseries.firstTime());
+    }
+    auto latestTime = std::max({now, cachedTime_, timeseries.getLatestTime()});
+    if (timeseries.isAllTime()) {
+      return latestTime - firstTime + Duration(1);
+    } else {
+      return latestTime -
+          std::max(
+                 firstTime, timeseries.getEarliestTrackableTimeBy(latestTime)) +
+          Duration(1);
+    }
+  }
+
+  std::pair<typename Level::Bucket, bool> totalBy(
+      size_t level, TimePoint now) const {
+    const auto& timeseries = getLevel(level);
+    if (cachedCount_ == 0) {
+      return {
+          timeseries.totalBy(std::max(now, timeseries.getLatestTime())), false};
+    }
+
+    // Regardless if cache value is still captured or not, we still need to
+    // rotate the buckets to the max timestamps.
+    auto latestTime = std::max({timeseries.getLatestTime(), now, cachedTime_});
+    if (timeseries.isAllTime()) {
+      return {timeseries.totalBy(latestTime), true};
+    }
+
+    // In order to decide if we should include cached value in the result or
+    // not, all we need to know is if cachedTime_ is still within the trackable
+    // window.
+    auto earliestTime = timeseries.getEarliestTrackableTimeBy(latestTime);
+    if (cachedTime_ < earliestTime) {
+      // Cached value is too old, and not tracked by the timeseries any more.
+      return {timeseries.totalBy(latestTime), false};
+    } else {
+      return {timeseries.totalBy(latestTime), true};
+    }
+  }
+
   std::vector<Level> levels_;
 
   // Updates within the same time interval are cached
@@ -434,6 +556,7 @@ class MultiLevelTimeSeries {
   TimePoint cachedTime_;
   ValueType cachedSum_;
   uint64_t cachedCount_;
+  Duration cacheDuration_;
 };
 
 } // namespace folly
