@@ -313,12 +313,15 @@ TEST_F(SynchronizedLockTest, TestCopyConstructibleValues) {
     NonCopyConstructible& operator=(const NonCopyConstructible&) = delete;
   };
   struct CopyConstructible {};
-  EXPECT_FALSE(std::is_copy_constructible<
-               folly::Synchronized<NonCopyConstructible>>::value);
-  EXPECT_FALSE(std::is_copy_assignable<
-               folly::Synchronized<NonCopyConstructible>>::value);
-  EXPECT_TRUE(std::is_copy_constructible<
-              folly::Synchronized<CopyConstructible>>::value);
+  EXPECT_FALSE(
+      std::is_copy_constructible<
+          folly::Synchronized<NonCopyConstructible>>::value);
+  EXPECT_FALSE(
+      std::is_copy_assignable<
+          folly::Synchronized<NonCopyConstructible>>::value);
+  EXPECT_TRUE(
+      std::is_copy_constructible<
+          folly::Synchronized<CopyConstructible>>::value);
   EXPECT_TRUE(
       std::is_copy_assignable<folly::Synchronized<CopyConstructible>>::value);
 }
@@ -1009,9 +1012,9 @@ class TestStruct {
 
 TEST(Synchronized, ConstexprConstructor) {
   // Make sure the folly::Synchronized constructor can be constexpr
-  static FOLLY_CONSTINIT folly::Synchronized<int> i{std::in_place, 5};
-  static FOLLY_CONSTINIT folly::Synchronized<TestStruct> ts1;
-  static FOLLY_CONSTINIT folly::Synchronized<TestStruct> ts2{std::in_place, 1};
+  static constinit folly::Synchronized<int> i{std::in_place, 5};
+  static constinit folly::Synchronized<TestStruct> ts1;
+  static constinit folly::Synchronized<TestStruct> ts2{std::in_place, 1};
 
   // Not constinit, since the int value will be uninitialized
   static folly::Synchronized<int> i2;
